@@ -13,7 +13,7 @@ load_api(os.environ.get("API_SPEC", "/var/task/api_spec.yaml"))
 adapter = GatewayAdapter()
 
 
-def lambda_handler(event, _):
+def handler(event, _):
     log.debug(f"event: {event}")
     try:
         response = adapter.process_event(event)
